@@ -1,8 +1,8 @@
+import rdkit.Chem.AllChem as rdkit  # noqa: N813
 import stk
-import rdkit.Chem.AllChem as rdkit
 
 
-def is_equivalent_atom(atom1, atom2):
+def is_equivalent_atom(atom1: stk.Atom, atom2: stk.Atom) -> None:
     assert atom1 is not atom2
     assert atom1.__class__ is atom2.__class__
     assert atom1.get_id() == atom2.get_id()
@@ -13,7 +13,8 @@ def is_equivalent_atom(atom1, atom2):
 _periodic_table = rdkit.GetPeriodicTable()
 
 atomic_numbers = {
-    stk.__dict__[_periodic_table.GetElementSymbol(atomic_number)]:
-        atomic_number
+    stk.__dict__[
+        _periodic_table.GetElementSymbol(atomic_number)
+    ]: atomic_number
     for atomic_number in range(1, 119)
 }
