@@ -1,23 +1,20 @@
+import numpy as np
 import pytest
 import stk
 
-
 _pd = stk.BuildingBlock(
-    smiles='[Pd+2]',
-    functional_groups=(
-        stk.SingleAtom(stk.Pd(0, charge=2))
-        for i in range(4)
-    ),
-    position_matrix=[[0, 0, 0]],
+    smiles="[Pd+2]",
+    functional_groups=(stk.SingleAtom(stk.Pd(0, charge=2)) for _ in range(4)),
+    position_matrix=np.array([[0, 0, 0]]),
 )
 
 # Define a bidentate ligand with two functional groups.
 _bidentate_ligand = stk.BuildingBlock(
-    smiles='NCCN',
+    smiles="NCCN",
     functional_groups=[
         stk.SmartsFunctionalGroupFactory(
-            smarts='[#7]~[#6]',
-            bonders=(0, ),
+            smarts="[#7]~[#6]",
+            bonders=(0,),
             deleters=(),
         ),
     ],
@@ -34,14 +31,10 @@ _complex = stk.ConstructedMolecule(
 
 @pytest.fixture(
     params=(
-        stk.BuildingBlock('NCCN'),
-        stk.BuildingBlock('c1ccccc1'),
+        stk.BuildingBlock("NCCN"),
+        stk.BuildingBlock("c1ccccc1"),
         _complex,
     ),
 )
-def molecule(request):
-    """
-    A :class:`.CaseData` instance.
-    """
-
+def molecule(request: pytest.FixtureRequest) -> stk.Molecule:
     return request.param
