@@ -1,16 +1,23 @@
-import stko
 from copy import deepcopy
-from ..utilities import (
+
+import stk
+
+import stko
+from tests.optimizers.optimizer.conftest import (
+    FailingOptimizer,
+    PassingOptimizer,
+)
+from tests.optimizers.utilities import (
     inequivalent_position_matrices,
     is_equivalent_molecule,
 )
 
 
 def test_optimizer_sequence(
-    passing_optimizer, unoptimized_mol
-):
-
-    opts = [deepcopy(passing_optimizer) for i in range(10)]
+    passing_optimizer: PassingOptimizer,
+    unoptimized_mol: stk.BuildingBlock,
+) -> None:
+    opts = [deepcopy(passing_optimizer) for _ in range(10)]
     opt_seq = stko.OptimizerSequence(*opts)
     opt_res = opt_seq.optimize(unoptimized_mol)
     is_equivalent_molecule(opt_res, unoptimized_mol)
@@ -18,9 +25,10 @@ def test_optimizer_sequence(
 
 
 def test_trycatchoptimizer(
-    passing_optimizer, failing_optimizer, unoptimized_mol,
-):
-
+    passing_optimizer: PassingOptimizer,
+    failing_optimizer: FailingOptimizer,
+    unoptimized_mol: stk.BuildingBlock,
+) -> None:
     opt = stko.TryCatchOptimizer(
         try_optimizer=failing_optimizer,
         catch_optimizer=passing_optimizer,
